Skip to main content

standupbrain

standupbrain reads your Git commit and Jira activity and passes them to a local LLM that reminds you what the heck you did yesterday.

Install

uv tool install standupbrain

Usage

Quickstart

  • Configure your GitHub credentials locally
  • Run standupbrain init to set up or reset your GitHub username, Git author email, Jira credentials, and preferred LLM model.
  • Run standupbrain recall to generate your standup summary.
    • Run --help or see below for additional options
    • Can run against other users but you won't get local commits (of course)

Help Commands

Check out the various --help options below:

standupbrain --help

Usage: standupbrain [OPTIONS] COMMAND [ARGS]...

  CLI for standupbrain, the tool to help you remember what you did yesterday

Options:
  --version  Show the version and exit.
  --help     Show this message and exit.

Commands:
  init    Initialize standupbrain with your preferred LLM and GitHub/Jira...
  recall  Generate a summary of what you did yesterday via GitHub/Jira ->...

standupbrain init --help

Usage: standupbrain init [OPTIONS]

  Initialize standupbrain with your preferred LLM and GitHub/Jira credentials

Options:
  --help  Show this message and exit.

standupbrain recall --help

Usage: standupbrain recall [OPTIONS]

  Generate a summary of what you did yesterday via GitHub/Jira -> LLM

Options:
  -e, --author-email TEXT     Git author email for searching local commits
  -d, --date [%Y-%m-%d]       Specific date to generate update for (YYYY-MM-
                              DD)
  --dry-run, --dry_run        Do not actually prompt the LLM, just query the
                              APIs and print the prompt
  -u, --github-username TEXT  GitHub account username for searching remotes in
                              GitHub
  -v, --verbose               High verbosity for debugging
  --help                      Show this message and exit.

Metadata

Release files for standupbrain 1.0.4

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for standupbrain 1.0.4
File Size Uploaded Provenance Actions
standupbrain-1.0.4.tar.gz 43.3 kB With provenance Details for standupbrain-1.0.4.tar.gz

Built distribution (wheel)

Table of built distributions (wheels) for standupbrain 1.0.4
File Interpreter ABI Platform Actions
standupbrain-1.0.4-py3-none-any.whl Python 3 none any Details for standupbrain-1.0.4-py3-none-any.whl

Total release size: 55.6 kB

Release files / standupbrain-1.0.4.tar.gz

Download URL standupbrain-1.0.4.tar.gz
Size 43.3 kB
Tags Source
SHA-256 checksum
How to use checksums
3e1a7f85c05381f900c4a4fd7fe37b592facdf4c36009dd3365b07896650e895
BLAKE2b-256 checksum
How to use checksums
fafc6f745fe9b5ece56164cfdf8c316209b0ed5f35080a81529c907e1073c0ff
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via twine/6.1.0 CPython/3.13.7

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

PyPI Publish Attestation

PyPI verified that this artifact, at this checksum, originated from the publisher listed below.

Signed by GitHub Actions, verified by PyPI on Nov 29, 2025.

Transparency log

Release files / standupbrain-1.0.4-py3-none-any.whl

Download URL standupbrain-1.0.4-py3-none-any.whl
Size 12.3 kB
Tags Python 3
SHA-256 checksum
How to use checksums
9d8df0b469ca10e0cd5d3bdc98739b19e0d40a47bf6f78f4e03eeaf30133bd9f
BLAKE2b-256 checksum
How to use checksums
e2e84f8408c8f3b8cc8d4b5e78eb5be275c786cce2a458a6c143eed1784927a0
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via twine/6.1.0 CPython/3.13.7

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

PyPI Publish Attestation

PyPI verified that this artifact, at this checksum, originated from the publisher listed below.

Signed by GitHub Actions, verified by PyPI on Nov 29, 2025.

Transparency log

Security for standupbrain 1.0.4

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

Full provenance

All 2 files in this release have been uploaded with provenance metadata.

Select from 2 files

Attestation for standupbrain-1.0.4.tar.gz

PyPI Publish Attestation

PyPI verified that this artifact, at this checksum, originated from the publisher listed below.

Signed by GitHub Actions, verified by PyPI on Nov 29, 2025.

Transparency log

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

To learn more about protecting yourself from malicious actors, visit our package security documentation.

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page